@@ -32,6 +32,7 @@ from pocsuite3.lib.core.register import load_file_to_module
 from pocsuite3.lib.core.settings import DEFAULT_LISTENER_PORT, CMD_PARSE_WHITELIST
 from pocsuite3.lib.core.statistics_comparison import StatisticsComparison
 from pocsuite3.lib.core.update import update
+from pocsuite3.lib.core.template import create_poc_plugin_template
 from pocsuite3.lib.parse.cmd import DIY_OPTIONS
 from pocsuite3.lib.parse.configfile import config_file_parser
 from pocsuite3.lib.parse.rules import regex_rule
@@ -213,8 +214,11 @@ def _set_multiple_targets():
 
     if conf.dork:
         # enable plugin 'target_from_zoomeye' by default
-        if ('target_from_shodan' not in conf.plugins and 'target_from_fofa' not in conf.plugins
-                and 'target_from_quake' not in conf.plugins):
+        if ('target_from_shodan' not in conf.plugins and
+                'target_from_censys' not in conf.plugins and
+                'target_from_fofa' not in conf.plugins and
+                'target_from_quake' not in conf.plugins and
+                'target_from_hunter' not in conf.plugins):
             conf.plugins.append('target_from_zoomeye')
 
     if conf.dork_zoomeye:
@@ -232,6 +236,9 @@ def _set_multiple_targets():
     if conf.dork_quake:
         conf.plugins.append('target_from_quake')
 
+    if conf.dork_hunter:
+        conf.plugins.append('target_from_hunter')
+
 
 def _set_task_queue():
     if kb.registered_pocs and kb.targets:
@@ -519,12 +526,16 @@ def _set_conf_attributes():
     conf.retry = 0
     conf.delay = 0
     conf.http_headers = {}
-    conf.login_user = None
-    conf.login_pass = None
+    conf.ceye_token = None
+    conf.oob_server = None
+    conf.oob_token = None
+    conf.seebug_token = None
+    conf.zoomeye_token = None
     conf.shodan_token = None
     conf.fofa_user = None
     conf.fofa_token = None
     conf.quake_token = None
+    conf.hunter_token = None
     conf.censys_uid = None
     conf.censys_secret = None
     conf.dork = None
@@ -532,6 +543,7 @@ def _set_conf_attributes():
     conf.dork_shodan = None
     conf.dork_fofa = None
     conf.dork_quake = None
+    conf.dork_hunter = None
     conf.dork_censys = None
     conf.dork_b64 = False
     conf.max_page = 1
@@ -545,6 +557,7 @@ def _set_conf_attributes():
     conf.check_requires = False
     conf.quiet = False
     conf.update_all = False
+    conf.new = False
     conf.verbose = 1
 
     conf.ipv6 = False
@@ -691,8 +704,8 @@ def _init_target_from_poc_dork():
             continue
         # find a available target source
         target_source = ''
-        for i in ["zoomeye", "fofa", "shodan", "quake", "censys"]:
-            if i in poc_class.dork.keys():
+        for i in ["zoomeye", "fofa", "shodan", "quake", "hunter", "censys"]:
+            if i in poc_class.dork.keys() and poc_class.dork[i].strip() != '':
                 target_source = i
                 break
         # fetch target from target source, add it to kb.targets
@@ -737,6 +750,7 @@ def init():
     _basic_option_validation()
     _create_directory()
     _init_kb_comparison()
+    create_poc_plugin_template()
     update()
     _set_multiple_targets()
     _set_user_pocs_path()
