@@ -1,21 +1,18 @@
+# pylint: disable=E1101
+import time
 import re
 import traceback
 import inspect
 from collections import OrderedDict
 
-from requests.exceptions import ConnectTimeout
-from requests.exceptions import ConnectionError
-from requests.exceptions import HTTPError
-from requests.exceptions import TooManyRedirects
-
-from pocsuite3.lib.core.common import parse_target_url, desensitization
-from pocsuite3.lib.core.data import conf
-from pocsuite3.lib.core.data import logger
+from requests.exceptions import ConnectTimeout, ConnectionError, HTTPError, TooManyRedirects
+from pocsuite3.lib.core.common import parse_target_url, desensitization, check_port, OrderedSet, get_host_ip
+from pocsuite3.lib.core.data import conf, logger
 from pocsuite3.lib.core.enums import OUTPUT_STATUS, CUSTOM_LOGGING, ERROR_TYPE_ID, POC_CATEGORY
 from pocsuite3.lib.core.exception import PocsuiteValidationException
 from pocsuite3.lib.core.interpreter_option import OptString, OptInteger, OptPort, OptBool
+from pocsuite3.lib.request import requests
 from pocsuite3.lib.utils import urlparse
-# for pocsuite 2.x
 
 
 class POCBase(object):
@@ -24,12 +21,16 @@ class POCBase(object):
         self.target = None
         self.headers = None
         self.url = None
+        self.scheme = None
+        self.rhost = None
+        self.rport = None
         self.mode = None
         self.params = None
         self.verbose = None
         self.expt = (0, 'None')
         self.current_protocol = getattr(self, "protocol", POC_CATEGORY.PROTOCOL.HTTP)
         self.pocDesc = getattr(self, "pocDesc", "Poc的作者好懒呀！")
+        self.host_ip = get_host_ip(check_private=False)
 
         # gloabl options init
         self.global_options = OrderedDict()
@@ -71,9 +72,9 @@ class POCBase(object):
     def get_option(self, name):
         if name not in self.options:
             raise PocsuiteValidationException
-        # 处理options中的payload,将Payload的IP和端口转换
+        # 处理options中的payload, 将Payload的IP和端口转换
         value = self.options[name].value
-        flag = re.search('\{0\}.+\{1\}', str(value))
+        flag = re.search(r'\{0\}.+\{1\}', str(value))
         if flag:
             value = value.format(conf.connect_back_host, conf.connect_back_port)
         return value
@@ -137,21 +138,20 @@ class POCBase(object):
             for k, v in option.items():
                 if v.require and v.value == "":
                     raise PocsuiteValidationException(
-                        "'{key}' must be set,please using command 'set {key}'".format(key=k))
+                        "'{key}' must be set, please using command 'set {key}'".format(key=k))
         return True
 
     def build_url(self):
-        if self.target and not conf.console_mode:
-            pr = urlparse(parse_target_url(self.target))
-            rport = pr.port if pr.port else 0
-            rhost = pr.hostname
-            ssl = False
-            if pr.scheme == 'https':
-                ssl = True
-            self.setg_option("rport", rport)
-            self.setg_option("rhost", rhost)
-            self.setg_option("ssl", ssl)
-        return parse_target_url(self.target)
+        target = parse_target_url(self.target)
+        pr = urlparse(target)
+        self.scheme = 'https' if pr.scheme.startswith('https') else 'http'
+        self.rhost = pr.hostname
+        self.rport = pr.port if pr.port else 443 if pr.scheme.startswith('https') else 80
+        if self.target and self.current_protocol != POC_CATEGORY.PROTOCOL.HTTP and not conf.console_mode:
+            self.setg_option("rport", self.rport)
+            self.setg_option("rhost", self.rhost)
+            self.setg_option("ssl", self.scheme == 'https')
+        return target
 
     def _execute(self):
         if self.mode == 'shell':
@@ -167,7 +167,11 @@ class POCBase(object):
 
     def execute(self, target, headers=None, params=None, mode='verify', verbose=True):
         self.target = target
-        self.url = parse_target_url(target) if self.current_protocol == POC_CATEGORY.PROTOCOL.HTTP else self.build_url()
+        self.url = self.build_url()
+        # TODO: Thread safe problem in self.headers
+        # https://github.com/knownsec/pocsuite3/issues/262
+        # The value should not be modified in PoC Plugin !!!
+        # Some PoC use this bug as a feature, For the purpose of PoC plugin compatibility, it will not be fixed
         self.headers = headers
         if isinstance(params, dict) or isinstance(params, str):
             self.params = params
@@ -218,7 +222,6 @@ class POCBase(object):
             logger.debug(str(e))
             output = Output(self)
 
-
         except BaseException as e:
             self.expt = (ERROR_TYPE_ID.OTHER, e)
             logger.error("PoC has raised a exception")
@@ -229,13 +232,100 @@ class POCBase(object):
             output.params = self.params
         return output
 
-    # def _shell(self):
-    #     """
-    #     @function   以Poc的shell模式对urls进行检测(具有危险性)
-    #                 需要在用户自定义的Poc中进行重写
-    #                 返回一个Output类实例
-    #     """
-    #     raise NotImplementedError
+    def _check(self, dork='', allow_redirects=False, return_obj=False, is_http=True, honeypot_check=True):
+        u = urlparse(self.url)
+        # the port closed
+        if u.port and not check_port(u.hostname, u.port):
+            logger.debug(f'{self.url}, the port is closed.')
+            return False
+
+        if not is_http:
+            return True
+
+        res = None
+        netloc = self.url.split('://', 1)[-1]
+        urls = OrderedSet()
+        urls.add(self.url)
+        urls.add(f'http://{netloc}')
+        urls.add(f'https://{netloc}')
+        for url in urls:
+            try:
+                time.sleep(0.5)
+                res = requests.get(url, allow_redirects=allow_redirects)
+                # access ok, the url need to be correct
+                if 'plain HTTP request was sent to HTTPS port' in res.text:
+                    self.url = f'https://{netloc}'
+                    res = requests.get(self.url, allow_redirects=allow_redirects)
+                    logger.warn(f'auto correct url to: {self.url}')
+                # another protocol is access ok
+                elif url != self.url:
+                    self.url = url
+                    logger.warn(f'auto correct url to: {self.url}')
+                break
+            except requests.ConnectionError:
+                pass
+
+        if return_obj:
+            return res
+
+        if res is None:
+            return False
+
+        content = str(res.headers).lower() + res.text.lower()
+        dork = dork.lower()
+
+        if dork not in content:
+            return False
+
+        if not honeypot_check:
+            return True
+
+        is_honeypot = False
+
+        # detect honeypot
+        # https://www.zoomeye.org/searchResult?q=%22GoAhead-Webs%22%20%2B%22Apache-Coyote%22
+        keyword = [
+            'goahead-webs',
+            'apache-coyote',
+            'upnp/',
+            'openresty',
+            'tomcat'
+        ]
+
+        sin = 0
+        for k in keyword:
+            if k in content:
+                sin += 1
+
+        if sin >= 3:
+            logger.debug(f'honeypot: sin({sin}) >= 3')
+            is_honeypot = True
+
+        # maybe some false positives
+        elif len(re.findall('<title>(.*)</title>', content)) > 5:
+            logger.debug('honeypot: too many title')
+            is_honeypot = True
+
+        elif len(re.findall('basic realm=', content)) > 5:
+            logger.debug('honeypot: too many www-auth')
+            is_honeypot = True
+
+        elif len(re.findall('server: ', content)) > 5:
+            logger.debug('honeypot: too many server')
+            is_honeypot = True
+
+        if is_honeypot:
+            logger.warn(f'{self.url} is a honeypot.')
+
+        return not is_honeypot
+
+    def _shell(self):
+        """
+        @function   以Poc的shell模式对urls进行检测(具有危险性)
+                    需要在用户自定义的Poc中进行重写
+                    返回一个Output类实例
+        """
+        raise NotImplementedError
 
     def _attack(self):
         """
@@ -253,6 +343,14 @@ class POCBase(object):
         """
         raise NotImplementedError
 
+    def parse_output(self, result={}):
+        output = Output(self)
+        if result:
+            output.success(result)
+        else:
+            output.fail('Internet nothing returned')
+        return output
+
     def _run(self):
         """
         @function   以Poc的GUI模式对url进行检测(可能具有危险性)
