@@ -1,7 +1,8 @@
+import time
 import getpass
 from configparser import ConfigParser
-from pocsuite3.lib.core.data import logger
-from pocsuite3.lib.core.data import paths
+from pocsuite3.lib.core.data import logger, paths
+from pocsuite3.lib.core.common import is_ipv6_address_format
 from pocsuite3.lib.request import requests
 
 
@@ -48,8 +49,7 @@ class Quake():
                 self.write_conf()
                 return True
             else:
-                logger.error("The Quake api token is incorrect. "
-                             "Please enter the correct api token.")
+                logger.error("The Quake api token is incorrect, Please enter the correct api token.")
 
     def write_conf(self):
         if not self.parser.has_section("Quake"):
@@ -66,15 +66,17 @@ class Quake():
                 "ignore_cache": "false", "start": 1}
         try:
             for page in range(1, pages + 1):
+                time.sleep(1)
                 data['start'] = page
                 url = "https://quake.360.cn/api/v3/search/quake_service"
-                resp = requests.post(
-                    url, json=data, headers=self.headers, timeout=80)
+                resp = requests.post(url, json=data, headers=self.headers, timeout=80)
                 if resp and resp.status_code == 200 and resp.json()['code'] == 0:
                     content = resp.json()
                     for match in content['data']:
-                        search_result.add("%s:%s" %
-                                          (match['ip'], match['port']))
+                        ip = match['ip']
+                        if is_ipv6_address_format(ip):
+                            ip = f'[{ip}]'
+                        search_result.add("%s:%s" % (ip, match['port']))
                 else:
                     logger.error("[PLUGIN] Quake:{}".format(resp.text))
         except Exception as ex:
